.. _contribute-to-this-documentation:

Contribute to this documentation
================================

The documentation is Charmcraft's first-person account of itself to the world. It
provides knowledge and guidance to people who use, study, and develop the project.

Charmcraft is built by many people, and its documentation voices the intent of its
developers and the practical needs of its users. As Charmcraft changes, so will people's
understanding and experience of it. Its documentation must therefore continuously evolve
in simpatico.

Canonical is intent on advancing the art and science of documentation, and Charmcraft is
a space for such innovation. This documentation is an application of ideas such as
`technical authoring
<https://ubuntu.com/blog/documentation-development-and-design-for-technical-authors>`_,
`Diátaxis <https://diataxis.fr>`_, and learning through self-driven practice.


Contributions
-------------

Because Charmcraft is open source and made possible by its community, it accommodates
insights into its operation and documentation from everyone. That includes you!

The Charmcraft team welcomes changes, suggestions, and questions. If you want to help
author the documentation, there are a few paths you can take:

* Make a change in the codebase. Learn how to do so in the project's `contributing guide
  <https://github.com/canonical/charmcraft/blob/main/CONTRIBUTING.md>`_.
* Request a change or report a problem on `GitHub
  <https://github.com/canonical/charmcraft>`_.
* Discuss your ideas on the `Charmcraft forum <https://discourse.charmhub.io>`_.
* Bring your experience and ideas to the `Charmcraft Matrix channel
  <https://matrix.to/#/#charmcraft:ubuntu.com>`_.
* Volunteer for a task in the :ref:`contribute-to-this-documentation-coda`.

Your contributions to the project are valuable. The team sees authorship as being on
equal footing with development.

Contributing offers an opportunity for professional growth and learning. You'll practice
technical writing and product testing, which are valuable skills you can bring to any
technical project. You'll also be collaborating with industry professionals and
Canonical employees in a public and visible way. Lastly, all contributors receive
recognition in the Charmcraft release that they work on.


.. _contribute-to-this-documentation-coda:

Canonical Open Documentation Academy
------------------------------------

The Canonical Open Documentation Academy (CODA) is a place where writers and developers
give hands-on help and mentoring to anyone wanting to participate in open source. It's
an initiative led by the documentation team at Canonical.

CODA provides:

* A space to debut in the open source community
* Guidance in choosing a first task in Charmcraft
* Direct support for contributions in Charmcraft and other projects
* Skill development in documentation and writing

Contributors gain experience with open source software, add to their professional
portfolio, connect with likeminded people, and receive recognition for giving back.

CODA coordinates work for open source projects everywhere, including Charmcraft. The
best way to get started is to volunteer for a topic in the `task aggregator`_ and read
`Get started as a contributor
<https://documentationacademy.org/docs/howto/get-started/>`_.


.. _task aggregator: https://github.com/canonical/open-documentation-academy/issues?q=is%3Aissue%20state%3Aopen%20charmcraft
